@@ -64,7 +64,7 @@ proc midi_popup {name buttonname varname devlist} {
     if {$::windowingsystem eq "win32"} {
         $name.popup configure -font menuFont
     }
-#    puts stderr [concat $devlist ]
+    #puts stderr [concat $devlist ]
     for {set x 0} {$x<[llength $devlist]} {incr x} {
         $name.popup add command -label [lindex $devlist $x] \
             -command [list midi_popup_action \
@@ -112,6 +112,7 @@ proc ::dialog_midi::pdtk_midi_dialog {id \
     set midi_alsaout [llength $midi_outdevlist]
 
     toplevel $id -class DialogWindow
+    wm withdraw $id
     wm title $id [_ "MIDI Settings"]
     wm group $id .
     wm resizable $id 0 0
@@ -407,12 +408,10 @@ proc ::dialog_midi::pdtk_midi_dialog {id \
         $id.buttonframe.cancel config -highlightthickness 0
     }
 
-    # set min size based on widget sizing
-    update
-    wm minsize $id [winfo width $id] [winfo height $id]
-
-    # wait a little for creation, then raise so it's on top
-    after 100 raise "$id"
+    # set min size based on widget sizing & pos over pdwindow
+    wm minsize $id [winfo reqwidth $id] [winfo reqheight $id]
+    position_over_window $id .pdwindow
+    raise $id
 }
 
 proc ::dialog_midi::pdtk_alsa_midi_dialog {id indev1 indev2 indev3 indev4 \
@@ -447,6 +446,7 @@ proc ::dialog_midi::pdtk_alsa_midi_dialog {id indev1 indev2 indev3 indev4 \
     set midi_alsaout [expr [llength $midi_outdevlist] - 1]
 
     toplevel $id -class DialogWindow
+    wm withdraw $id
     wm title $id [_ "ALSA MIDI Settings"]
     wm resizable $id 0 0
     wm transient $id
@@ -484,12 +484,10 @@ proc ::dialog_midi::pdtk_alsa_midi_dialog {id indev1 indev2 indev3 indev4 \
     pack $id.buttonframe.apply -side left -expand 1 -fill x -padx 15 -ipadx 10
     pack $id.buttonframe.ok -side left -expand 1 -fill x -padx 15 -ipadx 10
 
-    # set min size based on widget sizing
-    update
-    wm minsize $id [winfo width $id] [winfo height $id]
-
-    # wait a little for creation, then raise so it's on top
-    after 100 raise "$id"
+    # set min size based on widget sizing & pos over pdwindow
+    wm minsize $id [winfo reqwidth $id] [winfo reqheight $id]
+    position_over_window $id .pdwindow
+    raise "$id"
 }
 
 # for focus handling on OSX
